==> firexcode-0.7.6.tar.gz: lib/src/Laravel/laravel_controller.dart <==
// class LaravelTableController {
//   final String tableName;
//   final String functionCreate;
//   LaravelTableController({this.tableName, this.functionCreate});

//   String create({List<String> importModel}) {
//     var model = '';
//     importModel.forEach((element) {
//       model = model + 'use App\\' + element + ';\n';
//     });
//     var text = '''<?php

// namespace App\\Http\\Controllers\\Api;
// $model
// use App\\Http\\Controllers\\Controller;
// use App\\User;
// use Illuminate\\Support\\Facades\\Validator;
// use Illuminate\\Http\\Request;

// class ${tableName[0].toUpperCase()}${tableName.substring(1)}Controller extends Controller
// {
//    $functionCreate
// }
// ''';
//     return text;
//   }
// }

class LaravelTableController extends ControllerFunction<String> {
  LaravelTableController(
      {String tableName, String functionCreate, List<String> importModel})
      : super(tableName, functionCreate, importModel);
  var model = '';

  String get code {
    importModel.forEach((element) {
      model = model + 'use App\\' + element + ';\n';
    });
    return '''<?php

namespace App\\Http\\Controllers\\Api;
$model
use App\\Http\\Controllers\\Controller;
use App\\User;
use Illuminate\\Support\\Facades\\Validator;
use Illuminate\\Http\\Request;

class ${tableName[0].toUpperCase()}${tableName.substring(1)}Controller extends Controller
{
   $functionCreate
}
''';
  }
}

class ControllerFunction<T> {
  final T tableName;
  final T functionCreate;
  final List<String> importModel;
  ControllerFunction(this.tableName, this.functionCreate, this.importModel);
}

==> firexcode-0.7.9.tar.gz: lib/src/Laravel/laravel_controller.dart <==
// class LaravelTableController {
//   final String tableName;
//   final String functionCreate;
//   LaravelTableController({this.tableName, this.functionCreate});

//   String create({List<String> importModel}) {
//     var model = '';
//     importModel.forEach((element) {
//       model = model + 'use App\\' + element + ';\n';
//     });
//     var text = '''<?php

// namespace App\\Http\\Controllers\\Api;
// $model
// use App\\Http\\Controllers\\Controller;
// use App\\User;
// use Illuminate\\Support\\Facades\\Validator;
// use Illuminate\\Http\\Request;

// class ${tableName[0].toUpperCase()}${tableName.substring(1)}Controller extends Controller
// {
//    $functionCreate
// }
// ''';
//     return text;
//   }
// }

class LaravelTableController extends ControllerFunction<String> {
  LaravelTableController(
      {String tableName, String functionCreate, List<String> importModel})
      : super(tableName, functionCreate, importModel);
  var model = '';

  String get code {
    importModel.forEach((element) {
      model = model + 'use App\\' + element + ';\n';
    });
    return '''<?php

namespace App\\Http\\Controllers\\Api;
$model
use App\\Http\\Controllers\\Controller;
use App\\User;
use Illuminate\\Support\\Facades\\Validator;
use Illuminate\\Http\\Request;

class ${tableName[0].toUpperCase()}${tableName.substring(1).replaceAll('_', '')}Controller extends Controller
{
   $functionCreate
}
''';
  }
}

class ControllerFunction<T> {
  final T tableName;
  final T functionCreate;
  final List<String> importModel;
  ControllerFunction(this.tableName, this.functionCreate, this.importModel);
}
